%function v=compute_tangential_surge_d2_03(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
function v=compute_tangential_surge_d2_03(w,vt,a)
%function v=compute_tangential_surge_d2_03(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes tangential_surge_d2
% Script automatically generated by fit_tangential_surge_d2.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.64504
% RMSE  = 0.68256
% MEAN  = -2.2926
% RANGE = -4.7305 - -0.41894

beta( 1 )= -2.1574e+01 ;
beta( 2 )= 1.1781e+01 ;
beta( 3 )= 2.1976e+00 ;
beta( 4 )= 4.4304e+02 ;
beta( 5 )= 1.4567e-01 ;
beta( 6 )= -1.0047e+01 ;

v=beta(1) + beta(2)*vt.^beta(5) + beta(3)*exp(-w/beta(4)) + beta(6)*a;
